#define ACCOUNTS_SERVICE_ICON_DIR "/var/lib/AccountsService/icons"

#define HAVE_GETGROUPLIST 1

#define HAVE_DLADDR 1

#define HAVE_QTDBUS 1
